#!/bin/bash
set -e
declare -A env_api_ids
declare -A env_peering_maps
declare -A env_public_urls
ENV=${ENV:-localdev}

env_api_ids=(
  ["localdev"]="RULES_SERVICE_CONNECTOR_ID"
  ["dev01"]="BMN9JBHLDA"
  ["test03"]="F52R5317ZA"
  ["hub-dev-us"]="BMN9JBHLDA"
  ["hub04"]="F52R5317ZA"
  ["hub-prod-us"]="SVWL3F1VE9"
  ["hub-prod-eu"]="3S2T4WEQLF"
  ["hub-prod-ap"]="5U23FQ5AG6"
  ["hub-prod-ap2"]="NNH7E57VVD"
  ["eap01"]="SVWL3F1VE9"
  ["prod01"]="YBADC9Q3J3"
  ["prod02"]="I9PSUJWNW6"
  ["prod04"]="4Z65MSJGRR"
  ["prod05"]="WUQZQ9MTSH"
  ["prod06"]="3S2T4WEQLF"
  ["prodnrt"]="5U23FQ5AG6"
  ["prodsyd"]="NNH7E57VVD"
)

env_peering_maps=(
  ["localdev"]="localdev"
  ["dev01"]="dev01"
  ["test03"]="test03"
  ["hub-dev-us"]="hub-dev-us,dev01"
  ["hub04"]="hub04,test03"
  ["hub-prod-us"]="hub-prod-us,eap01,prod01,prod02,prod04,prod05"
  ["hub-prod-eu"]="hub-prod-eu,prod06"
  ["hub-prod-ap"]="hub-prod-ap,prodnrt"
  ["hub-prod-ap2"]="hub-prod-ap2,prodsyd"
  ["eap01"]="eap01"
  ["prod01"]="prod01"
  ["prod02"]="prod02"
  ["prod04"]="prod04"
  ["prod05"]="prod05"
  ["prod06"]="prod06"
  ["prodnrt"]="prodnrt"
  ["prodsyd"]="prodsyd"
)

env_public_urls=(
  ["localdev"]="localhost:8900"
  ["dev01"]="defense-dev01.cbdtest.io"
  ["test03"]="defense-test03.cbdtest.io"
  ["eap01"]="defense-eap01.conferdeploy.net"
  ["prod01"]="dashboard.confer.net"
  ["prod02"]="defense.conferdeploy.net"
  ["prod04"]="blackrock.confer.net"
  ["prod05"]="defense-prod05.conferdeploy.net"
  ["prod06"]="defense-eu.conferdeploy.net"
  ["prodnrt"]="defense-prodnrt.conferdeploy.net"
  ["prodsyd"]="defense-prodsyd.conferdeploy.net"
)

export RULES_SERVICE_API_ENVS=${env_peering_maps[$ENV]}

if [ "${ENV}" == "localdev" ]; then

    export AWS_REGION="us-east-1"
    export GATEWAY_PUBLIC_URLS="localhost:8900"
    export GATEWAY_INTERNAL_ADDRESS="psc.gateway:8900"
    export RULES_SERVICE_API_IDS="RULES_SERVICE_CONNECTOR_ID"
    export RULES_SERVICE_API_SECRETS="RULES_SERVICE_CONNECTOR_SECRET"
    export CMS_S3_ENDPOINT="http://cps-mockaws:4572"
    export CMS_AWS_REGION="us-east-1"

else
  # Primary Datasource
  export SPRING_PRIMARY_DATASOURCE_URL=jdbc:postgresql://${AURORA_WRITER_ENDPOINT}:${AURORA_PORT}/${AURORA_DB_NAME}${JDBC_OPTS}
  export SPRING_PRIMARY_DATASOURCE_USERNAME=${AURORA_USER}
  export SPRING_PRIMARY_DATASOURCE_PASSWORD=${AURORA_PASSWORD}

  # Replica Datasource
  export SPRING_REPLICA_DATASOURCE_URL=jdbc:postgresql://${AURORA_READER_ENDPOINT}:${AURORA_PORT}/${AURORA_DB_NAME}${JDBC_OPTS}
  export SPRING_REPLICA_DATASOURCE_USERNAME=${AURORA_USER}
  export SPRING_REPLICA_DATASOURCE_PASSWORD=${AURORA_PASSWORD}


  for env_name in  $(echo "${RULES_SERVICE_API_ENVS}" | sed "s/,/ /g")
  do
    ENV_SECRET_NAME=$(echo $env_name | tr a-z A-Z | sed 's/-/_/g')_RULES_CONNECTOR_SECRET
    env_secret=${!ENV_SECRET_NAME}
    RULES_SERVICE_API_SECRETS="$RULES_SERVICE_API_SECRETS,$env_secret"
    RULES_SERVICE_API_IDS="$RULES_SERVICE_API_IDS,${env_api_ids[$env_name]}"
    if [[ -v env_public_urls[$env_name] ]]; then
        echo "public gateway URL: ${env_public_urls[$env_name]}"
        GATEWAY_PUBLIC_URLS="$GATEWAY_PUBLIC_URLS,${env_public_urls[$env_name]}"
    fi
  done

   export RULES_SERVICE_API_SECRETS=$(echo $RULES_SERVICE_API_SECRETS | sed 's/,//')
   export RULES_SERVICE_API_IDS=$(echo $RULES_SERVICE_API_IDS | sed 's/,//')

   export GATEWAY_PUBLIC_URLS=$(echo $GATEWAY_PUBLIC_URLS | sed 's/,//')
   export GATEWAY_INTERNAL_ADDRESS="gateway.psc.internal:8903"
fi

echo "Using AWS_DEFAULT_REGION=$AWS_DEFAULT_REGION"
echo "Using ENV="$ENV
echo "Using writer postgres url"=$SPRING_PRIMARY_DATASOURCE_URL
echo "Using reader postgres url"=$SPRING_REPLICA_DATASOURCE_URL
echo "Using writer postgres user"=$SPRING_PRIMARY_DATASOURCE_USERNAME
echo "Using reader postgres user"=$SPRING_REPLICA_DATASOURCE_USERNAME
exec "$@"